/* -*- Mode: C; indent-tabs-mode: t; tab-width: 2; c-basic-offset: 2 -*- */
/* GtkTrue - Be GtkTrue to yourself! :P
 * Copyright  1999 Joachim Nilsson <joachim.nilsson@mds.mdh.se>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

GtkWidget*
create_base_window (char *message)
{
  GtkWidget *base_window;
  GtkWidget *vbox;
  GtkWidget *hbox;
  GtkWidget *pixmap;
  GtkWidget *text_label;
  GtkWidget *hseparator;
  GtkWidget *hbuttonbox;
  GtkWidget *ok_button;

  base_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (base_window, "base_window");
  gtk_object_set_data (GTK_OBJECT (base_window), "base_window", base_window);
  gtk_container_set_border_width (GTK_CONTAINER (base_window), 2);
  gtk_window_set_title (GTK_WINDOW (base_window), _("GTKtrue"));
  gtk_window_set_policy (GTK_WINDOW (base_window), FALSE, FALSE, FALSE);

  vbox = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox, "vbox");
  gtk_object_set_data (GTK_OBJECT (base_window), "vbox", vbox);
  gtk_widget_show (vbox);
  gtk_container_add (GTK_CONTAINER (base_window), vbox);

  hbox = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox, "hbox");
  gtk_object_set_data (GTK_OBJECT (base_window), "hbox", hbox);
  gtk_widget_show (hbox);
  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);

  pixmap = create_pixmap (base_window, "info.xpm");
  gtk_widget_set_name (pixmap, "pixmap");
  gtk_object_set_data (GTK_OBJECT (base_window), "pixmap", pixmap);
  gtk_widget_show (pixmap);
  gtk_box_pack_start (GTK_BOX (hbox), pixmap, TRUE, TRUE, 0);
  gtk_misc_set_padding (GTK_MISC (pixmap), 1, 1);

	if (message)
		text_label = gtk_label_new (message);
	else
		text_label = gtk_label_new (_("  It is true.                         "));
  gtk_widget_set_name (text_label, "text_label");
  gtk_object_set_data (GTK_OBJECT (base_window), "text_label", text_label);
  gtk_widget_show (text_label);
  gtk_box_pack_start (GTK_BOX (hbox), text_label, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (text_label), GTK_JUSTIFY_LEFT);

  hseparator = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator, "hseparator");
  gtk_object_set_data (GTK_OBJECT (base_window), "hseparator", hseparator);
  gtk_widget_show (hseparator);
  gtk_box_pack_start (GTK_BOX (vbox), hseparator, TRUE, TRUE, 0);

  hbuttonbox = gtk_hbutton_box_new ();
  gtk_widget_set_name (hbuttonbox, "hbuttonbox");
  gtk_object_set_data (GTK_OBJECT (base_window), "hbuttonbox", hbuttonbox);
  gtk_widget_show (hbuttonbox);
  gtk_box_pack_start (GTK_BOX (vbox), hbuttonbox, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox), 3);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);

  ok_button = gtk_button_new_with_label (_("OK"));
  gtk_widget_set_name (ok_button, "ok_button");
  gtk_object_set_data (GTK_OBJECT (base_window), "ok_button", ok_button);
  gtk_widget_show (ok_button);
  gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
  GTK_WIDGET_SET_FLAGS (ok_button, GTK_CAN_DEFAULT);
  gtk_widget_grab_focus (ok_button);
  gtk_widget_grab_default (ok_button);

  gtk_signal_connect (GTK_OBJECT (ok_button), "clicked",
                      GTK_SIGNAL_FUNC (on_ok_button_clicked),
                      NULL);

  return base_window;
}

